#
# spec file for package projectM
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           projectM
Version:        2.1.0
Release:        32.1
Summary:        An Awesome Music Visualizer
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Sound/Visualization
Url:            http://projectm.sourceforge.net
Source0:        %{name}-%{version}.tar.bz2
Source1:        FindGLEW.cmake
# PATCH-FIX-UPSTREAM projectM-2.1.0-fix-isnan-gcc6.patch -- fix build with GCC6 (patch from upstream development branch)
Patch0:         projectM-2.1.0-fix-isnan-gcc6.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  ftgl-devel
BuildRequires:  glew-devel
BuildRequires:  SDL-devel
BuildRequires:  libpulse-devel
BuildRequires:  libqt4-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libvisual-devel
BuildRequires:  update-desktop-files
Recommends:     %{name}-data = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
projectM is an awesome music visualizer.

%package -n lib%{name}2
Summary:        Run-time Libraries for ProjectM
Group:          System/Libraries

%description -n lib%{name}2
projectM is an awesome music visualizer.
This package contains its runtime libraries.

%package -n lib%{name}-qt1
Summary:        Qt Run-time Libraries for ProjectM
Group:          System/Libraries

%description -n lib%{name}-qt1
projectM is an awesome music visualizer.
This package contains its qt runtime libraries.

%package -n lib%{name}-libvisual
Summary:        Libvisual Collaboration for ProjectM
Group:          System/Libraries

%description -n lib%{name}-libvisual
projectM is an awesome music visualizer.
This package contains its libvisual collaboration libraries.

%package data
Summary:        Data files for ProjectM
Group:          Productivity/Multimedia/Sound/Visualization
Requires:       %{name} = %{version}
Requires:       dejavu

%description data
projectM is an awesome music visualizer.
This package contains its data: config, presets, shaders.

%package devel
Summary:        Development Files for ProjectM
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}-data = %{version}
Requires:       lib%{name}-qt1 = %{version}
Requires:       lib%{name}2 = %{version}

%description devel
projectM is an awesome music visualizer.
This package contains its development files.

%prep
%setup -q
%patch0 -p1

rm -r src/WinLibs # legal issues, see bnc#738417, we don't need that whole tree

%build
mkdir -pv src/build
cp -r %{SOURCE1} src/projectM-pulseaudio/
pushd src/build

if [ %{_lib} = lib64 ]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -DLIB_SUFFIX=64"
fi

#projectM-test has link problems, I don't know how to fix, so disable it
cmake -DCMAKE_INSTALL_PREFIX=/usr $EXTRA_FLAGS \
      -DINCLUDE-PROJECTM-TEST=OFF \
      ..

make %{?_smp_mflags}

%install
pushd src/build
%make_install
popd
%fdupes %{buildroot}
%suse_update_desktop_file -n %{buildroot}%{_datadir}/applications/%{name}-pulseaudio.desktop Mixer

%if "%{_lib}" == "lib64"
mv %{buildroot}%{_prefix}/lib/* %{buildroot}%{_libdir}
%endif

sed -i 's:^Title Font.*$:Title Font = /usr/share/fonts/truetype/DejaVuSans.ttf:' %{buildroot}%{_datadir}/projectM/config.inp
sed -i 's:^Menu Font.*$:Menu Font = /usr/share/fonts/truetype/DejaVuSansMono.ttf:' %{buildroot}%{_datadir}/projectM/config.inp

%clean
rm -rf %{buildroot}

%post -n lib%{name}2 -p /sbin/ldconfig
%post -n lib%{name}-qt1 -p /sbin/ldconfig
%post -n lib%{name}-libvisual -p /sbin/ldconfig
%postun -n lib%{name}2 -p /sbin/ldconfig
%postun -n lib%{name}-qt1 -p /sbin/ldconfig
%postun -n lib%{name}-libvisual -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/%{name}-pulseaudio
#%{_bindir}/%{name}-test
#%{_bindir}/%{name}-test-texture
%{_datadir}/applications/%{name}-pulseaudio.desktop
%{_datadir}/pixmaps/*

%files -n lib%{name}2
%defattr(-,root,root)
%{_libdir}/lib%{name}.so.%{version}

%files -n lib%{name}-qt1
%defattr(-,root,root)
%{_libdir}/lib%{name}-qt.so.1.10

%files -n lib%{name}-libvisual
%defattr(-,root,root)
%{_libdir}/libvisual-0.4/

%files data
%defattr(-,root,root)
%{_datadir}/%{name}/

%files devel
%defattr(-,root,root)
%{_includedir}/lib%{name}
%{_includedir}/lib%{name}-qt/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}.so.2
%{_libdir}/lib%{name}-qt.so
%{_libdir}/lib%{name}-qt.so.1
%{_libdir}/pkgconfig/*

%changelog
* Mon May 23 2016 antoine.belvire@laposte.net
- Fix build with GCC6:
  * Add projectM-2.1.0-fix-isnan-gcc6.patch
* Thu Dec 11 2014 olaf@aepfle.de
- Correct usage of fdupes macro
* Tue Jun 25 2013 i@marguerite.su
- fix bnc#825162: Error in standard configuration File causes projectM not to start
* Sun Mar 24 2013 schwab@suse.de
- Properly determine list of lib64 platforms
* Thu May 24 2012 i@marguerite.su
- update version 2.1.0
  * Fixed several memory leaks (when projectM gets destroyed, or when a preset gets destroyed)
  * Resolved some parser errors and an embarrasing evaluation bug (in particular, 2^x does not equal x^2)
  * +/- keys support to edit the ratings
  * libvisual / gstreamer compatible
  * Various cmake build fixes and improvements
- drop two patches. upstream fixed.
* Sat May 12 2012 reddwarf@opensuse.org
- fix the version in the pkg-config file
* Tue Mar 27 2012 dvaleev@suse.com
- fix ppc64 build
* Tue Jan  3 2012 saschpe@suse.de
- Remove licenses from subpackages (inherited anyways)
- Remove src/WinLibs tree (bnc#738417)
* Sat Dec 31 2011 prusnak@opensuse.org
- spec cleanup
- fix font locations in config.inp
* Sat Dec 10 2011 i@marguerite.su
- initial package 2.0.1+ from git
- split libraries and data
